PushKitConfig class
PushKit initialization config.
Constructors
-
PushKitConfig({String? androidPushAction, String? androidNotificationEntranceClassName, bool registerIOSRemoteNotifications = true, List<
PushKitPayloadParser> customParsers = const <PushKitPayloadParser>[]}) -
const
Properties
- androidNotificationEntranceClassName → String?
-
Optional custom Android notification entrance activity class name.
final
- androidPushAction → String?
-
Optional custom Android notification click action.
final
-
customParsers
→ List<
PushKitPayloadParser> -
Custom payload parsers. The first non-null result wins.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- registerIOSRemoteNotifications → bool
-
Request APNS permission and register remote notifications on iOS.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited